<?php
/**
 * Law Firm Lite Theme Customizer
 *
 * @package Law Firm Lite
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */

function law_firm_lite_custom_controls() {
	load_template( trailingslashit( get_template_directory() ) . '/inc/custom-controls.php' );
}
add_action( 'customize_register', 'law_firm_lite_custom_controls' );

function law_firm_lite_customize_register( $wp_customize ) {

	load_template( trailingslashit( get_template_directory() ) . 'inc/customize-homepage/class-customize-homepage.php' );

	//add home page setting pannel
	$wp_customize->add_panel( 'law_firm_lite_panel_id', array(
	    'priority' => 10,
	    'capability' => 'edit_theme_options',
	    'theme_supports' => '',
	    'title' => __( 'VW Settings', 'law-firm-lite' ),
	) );

	// Layout
	$wp_customize->add_section( 'law_firm_lite_left_right', array(
    	'title'      => __( 'General Settings', 'law-firm-lite' ),
		'panel' => 'law_firm_lite_panel_id'
	) );

	$wp_customize->add_setting('law_firm_lite_theme_options',array(
        'default' => __('Right Sidebar','law-firm-lite'),
        'sanitize_callback' => 'law_firm_lite_sanitize_choices'
	));
	$wp_customize->add_control('law_firm_lite_theme_options',array(
        'type' => 'select',
        'label' => __('Post Sidebar Layout','law-firm-lite'),
        'description' => __('Here you can change the sidebar layout for posts. ','law-firm-lite'),
        'section' => 'law_firm_lite_left_right',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','law-firm-lite'),
            'Right Sidebar' => __('Right Sidebar','law-firm-lite'),
            'One Column' => __('One Column','law-firm-lite'),
            'Three Columns' => __('Three Columns','law-firm-lite'),
            'Four Columns' => __('Four Columns','law-firm-lite'),
            'Grid Layout' => __('Grid Layout','law-firm-lite')
        ),
	) );

	$wp_customize->add_setting('law_firm_lite_page_layout',array(
        'default' => __('One Column','law-firm-lite'),
        'sanitize_callback' => 'law_firm_lite_sanitize_choices'
	));
	$wp_customize->add_control('law_firm_lite_page_layout',array(
        'type' => 'select',
        'label' => __('Page Sidebar Layout','law-firm-lite'),
        'description' => __('Here you can change the sidebar layout for pages. ','law-firm-lite'),
        'section' => 'law_firm_lite_left_right',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','law-firm-lite'),
            'Right Sidebar' => __('Right Sidebar','law-firm-lite'),
            'One Column' => __('One Column','law-firm-lite')
        ),
	) );

	//Top Bar
	$wp_customize->add_section( 'law_firm_lite_topbar', array(
    	'title'      => __( 'Top Bar Settings', 'law-firm-lite' ),
		'panel' => 'law_firm_lite_panel_id'
	) );

	$wp_customize->add_setting('law_firm_lite_location',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('law_firm_lite_location',array(
		'label'	=> __('Add Location','law-firm-lite'),
		'input_attrs' => array(
            'placeholder' => __( '123 Dunmmy street lorem ipsum, USA', 'law-firm-lite' ),
        ),
		'section'=> 'law_firm_lite_topbar',
		'type'=> 'text'
	));

	$wp_customize->add_setting('law_firm_lite_open_time',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('law_firm_lite_open_time',array(
		'label'	=> __('Add Opening Time','law-firm-lite'),
		'input_attrs' => array(
            'placeholder' => __( 'Mon to Sat 9:00am - 8:00pm', 'law-firm-lite' ),
        ),
		'section'=> 'law_firm_lite_topbar',
		'type'=> 'text'
	));

	$wp_customize->add_setting('law_firm_lite_top_btn_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('law_firm_lite_top_btn_text',array(
		'label'	=> __('Add Button Text','law-firm-lite'),
		'input_attrs' => array(
            'placeholder' => __( 'FREE EVALUATION', 'law-firm-lite' ),
        ),
		'section'=> 'law_firm_lite_topbar',
		'type'=> 'text'
	));

	$wp_customize->add_setting('law_firm_lite_top_btn_url',array(
		'default'=> '',
		'sanitize_callback'	=> 'esc_url_raw'
	));
	$wp_customize->add_control('law_firm_lite_top_btn_url',array(
		'label'	=> __('Add Button URL','law-firm-lite'),
		'input_attrs' => array(
            'placeholder' => __( 'https://example.com/', 'law-firm-lite' ),
        ),
		'section'=> 'law_firm_lite_topbar',
		'type'=> 'url'
	));

	$wp_customize->add_setting( 'law_firm_lite_header_search',array(
    	'default' => 1,
      	'transport' => 'refresh',
      	'sanitize_callback' => 'law_firm_lite_switch_sanitization'
    ));  
    $wp_customize->add_control( new Law_Firm_Lite_Toggle_Switch_Custom_control( $wp_customize, 'law_firm_lite_header_search',array(
      	'label' => esc_html__( 'Show / Hide Search','law-firm-lite' ),
      	'section' => 'law_firm_lite_topbar'
    )));
    
	//Slider
	$wp_customize->add_section( 'law_firm_lite_slidersettings' , array(
    	'title'      => __( 'Slider Settings', 'law-firm-lite' ),
		'panel' => 'law_firm_lite_panel_id'
	) );

	$wp_customize->add_setting( 'law_firm_lite_slider_arrows',array(
    	'default' => 1,
      	'transport' => 'refresh',
      	'sanitize_callback' => 'law_firm_lite_switch_sanitization'
    ));  
    $wp_customize->add_control( new Law_Firm_Lite_Toggle_Switch_Custom_control( $wp_customize, 'law_firm_lite_slider_arrows',array(
      	'label' => esc_html__( 'Show / Hide Slider','law-firm-lite' ),
      	'section' => 'law_firm_lite_slidersettings'
    )));

	for ( $count = 1; $count <= 4; $count++ ) {

		$wp_customize->add_setting( 'law_firm_lite_slider_page' . $count, array(
			'default'           => '',
			'sanitize_callback' => 'law_firm_lite_sanitize_dropdown_pages'
		) );
		$wp_customize->add_control( 'law_firm_lite_slider_page' . $count, array(
			'label'    => __( 'Select Slider Page', 'law-firm-lite' ),
			'description' => __('Slider image size (1500 x 800)','law-firm-lite'),
			'section'  => 'law_firm_lite_slidersettings',
			'type'     => 'dropdown-pages'
		) );
	}

	//Contact
	$wp_customize->add_section( 'law_firm_lite_contact', array(
    	'title'      => __( 'Contact Settings', 'law-firm-lite' ),
		'panel' => 'law_firm_lite_panel_id'
	) );

	$wp_customize->add_setting('law_firm_lite_calling_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('law_firm_lite_calling_text',array(
		'label'	=> __('Add Calling Text','law-firm-lite'),
		'input_attrs' => array(
            'placeholder' => __( 'Call us for free consultation', 'law-firm-lite' ),
        ),
		'section'=> 'law_firm_lite_contact',
		'type'=> 'text'
	));

	$wp_customize->add_setting('law_firm_lite_calling_number',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('law_firm_lite_calling_number',array(
		'label'	=> __('Add Calling Number','law-firm-lite'),
		'input_attrs' => array(
            'placeholder' => __( '+00 1234 654 654', 'law-firm-lite' ),
        ),
		'section'=> 'law_firm_lite_contact',
		'type'=> 'text'
	));

	$wp_customize->add_setting('law_firm_lite_email_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('law_firm_lite_email_text',array(
		'label'	=> __('Add Email Text','law-firm-lite'),
		'input_attrs' => array(
            'placeholder' => __( 'Drop us Mail', 'law-firm-lite' ),
        ),
		'section'=> 'law_firm_lite_contact',
		'type'=> 'text'
	));

	$wp_customize->add_setting('law_firm_lite_email_address',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('law_firm_lite_email_address',array(
		'label'	=> __('Add Email Address','law-firm-lite'),
		'input_attrs' => array(
            'placeholder' => __( 'example@123.com', 'law-firm-lite' ),
        ),
		'section'=> 'law_firm_lite_contact',
		'type'=> 'text'
	));
    
	//Our Practise Area section
	$wp_customize->add_section( 'law_firm_lite_services_section' , array(
    	'title'      => __( 'Our Practice Area', 'law-firm-lite' ),
		'priority'   => null,
		'panel' => 'law_firm_lite_panel_id'
	) );

	$wp_customize->add_setting('law_firm_lite_section_title',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('law_firm_lite_section_title',array(
		'label'	=> __('Add Section Title','law-firm-lite'),
		'input_attrs' => array(
            'placeholder' => __( 'Our Practise Areas', 'law-firm-lite' ),
        ),
		'section'=> 'law_firm_lite_services_section',
		'type'=> 'text'
	));

	$wp_customize->add_setting('law_firm_lite_section_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('law_firm_lite_section_text',array(
		'label'	=> __('Add Section Text','law-firm-lite'),
		'input_attrs' => array(
            'placeholder' => __( 'HIGH LEVEL SERVICES', 'law-firm-lite' ),
        ),
		'section'=> 'law_firm_lite_services_section',
		'type'=> 'text'
	));

	$categories = get_categories();
	$cat_post = array();
	$cat_post[]= 'select';
	$i = 0;	
	foreach($categories as $category){
		if($i==0){
			$default = $category->slug;
			$i++;
		}
		$cat_post[$category->slug] = $category->name;
	}

	$wp_customize->add_setting('law_firm_lite_our_services',array(
		'default'	=> 'select',
		'sanitize_callback' => 'law_firm_lite_sanitize_choices',
	));
	$wp_customize->add_control('law_firm_lite_our_services',array(
		'type'    => 'select',
		'choices' => $cat_post,
		'label' => __('Select Category to display Services','law-firm-lite'),
		'description' => __('Image Size (370 x 370)','law-firm-lite'),
		'section' => 'law_firm_lite_services_section',
	));

	//Content Craetion
	$wp_customize->add_section( 'law_firm_lite_content_section' , array(
    	'title' => __( 'Customize Home Page Settings', 'law-firm-lite' ),
		'priority' => null,
		'panel' => 'law_firm_lite_panel_id'
	) );

	$wp_customize->add_setting('law_firm_lite_content_creation_main_control', array(
		'sanitize_callback' => 'esc_html',
	) );

	$homepage= get_option( 'page_on_front' );

	$wp_customize->add_control(	new Law_Firm_Lite_Content_Creation( $wp_customize, 'law_firm_lite_content_creation_main_control', array(
		'options' => array(
			esc_html__( 'First select static page in homepage setting for front page.Below given edit button is to customize Home Page. Just click on the edit option, add whatever elements you want to include in the homepage, save the changes and you are good to go.','law-firm-lite' ),
		),
		'section' => 'law_firm_lite_content_section',
		'button_url'  => admin_url( 'post.php?post='.$homepage.'&action=edit'),
		'button_text' => esc_html__( 'Edit', 'law-firm-lite' ),
	) ) );

	//Footer Text
	$wp_customize->add_section('law_firm_lite_footer',array(
		'title'	=> __('Footer Settings','law-firm-lite'),
		'panel' => 'law_firm_lite_panel_id',
	));	
	
	$wp_customize->add_setting('law_firm_lite_footer_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('law_firm_lite_footer_text',array(
		'label'	=> __('Copyright Text','law-firm-lite'),
		'input_attrs' => array(
            'placeholder' => __( 'Copyright 2019, .....', 'law-firm-lite' ),
        ),
		'section'=> 'law_firm_lite_footer',
		'type'=> 'text'
	));	
}

add_action( 'customize_register', 'law_firm_lite_customize_register' );

load_template( trailingslashit( get_template_directory() ) . '/inc/logo/logo-resizer.php' );

/**
 * Singleton class for handling the theme's customizer integration.
 *
 * @since  1.0.0
 * @access public
 */
final class Law_Firm_Lite_Customize {

	/**
	 * Returns the instance.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return object
	 */
	public static function get_instance() {

		static $instance = null;

		if ( is_null( $instance ) ) {
			$instance = new self;
			$instance->setup_actions();
		}

		return $instance;
	}

	/**
	 * Constructor method.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function __construct() {}

	/**
	 * Sets up initial actions.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function setup_actions() {

		// Register panels, sections, settings, controls, and partials.
		add_action( 'customize_register', array( $this, 'sections' ) );

		// Register scripts and styles for the controls.
		add_action( 'customize_controls_enqueue_scripts', array( $this, 'enqueue_control_scripts' ), 0 );
	}

	/**
	 * Sets up the customizer sections.
	 *
	 * @since  1.0.0
	 * @access public
	 * @param  object  $manager
	 * @return void
	*/
	public function sections( $manager ) {

		// Load custom sections.
		load_template( trailingslashit( get_template_directory() ) . '/inc/section-pro.php' );

		// Register custom section types.
		$manager->register_section_type( 'Law_Firm_Lite_Customize_Section_Pro' );

		// Register sections.
		$manager->add_section( new Law_Firm_Lite_Customize_Section_Pro( $manager,'example_1', array(
			'priority'   => 9,
			'title'    => esc_html__( 'LAW FRIM PRO', 'law-firm-lite' ),
			'pro_text' => esc_html__( 'UPGRADE PRO', 'law-firm-lite' ),
			'pro_url'  => esc_url('https://www.vwthemes.com/themes/law-firm-wordpress-theme/'),
		) )	);
	}

	/**
	 * Loads theme customizer CSS.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return void
	 */
	public function enqueue_control_scripts() {

		wp_enqueue_script( 'law-firm-lite-customize-controls', trailingslashit( get_template_directory_uri() ) . '/assets/js/customize-controls.js', array( 'customize-controls' ) );

		wp_enqueue_style( 'law-firm-lite-customize-controls', trailingslashit( get_template_directory_uri() ) . '/assets/css/customize-controls.css' );
	}
}

// Doing this customizer thang!
Law_Firm_Lite_Customize::get_instance();